import { useRef, forwardRef } from 'react';
import PropTypes from 'prop-types';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState/index.js';
import { PLACEMENTS, TRIGGERS, BASE_CLASS, CLASS_INNER, PREFIX_PLACEMENT, DEFAULT_OFFSET, DEFAULT_TRIGGER, DEFAULT_DELAY, Popover } from './config.js';
import PopoverExtendChildren from './PopoverExtendChildren.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var AtomPopover = /*#__PURE__*/forwardRef(function (_ref, outRef) {
  var children = _ref.children,
      closeIcon = _ref.closeIcon,
      content = _ref.content,
      onClose = _ref.onClose,
      onOpen = _ref.onOpen,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? PLACEMENTS.BOTTOM : _ref$placement,
      isVisible = _ref.isVisible,
      defaultIsVisible = _ref.defaultIsVisible,
      _ref$hideArrow = _ref.hideArrow,
      hideArrow = _ref$hideArrow === void 0 ? true : _ref$hideArrow,
      _ref$trigger = _ref.trigger,
      trigger = _ref$trigger === void 0 ? DEFAULT_TRIGGER : _ref$trigger;
  var targetRef = useRef();

  var _useControlledState = useControlledState(isVisible, defaultIsVisible),
      isVisibleState = _useControlledState[0],
      setIsVisibleState = _useControlledState[1];

  var handleToggle = function handleToggle(ev) {
    setIsVisibleState(!isVisibleState);
    isVisibleState ? typeof onClose === 'function' && onClose(ev) : typeof onOpen === 'function' && onOpen(ev);
  };

  var ContentComponent = typeof content === 'function' ? content : function () {
    return content;
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(PopoverExtendChildren, {
      ref: targetRef,
      onToggle: handleToggle,
      children: children
    }), /*#__PURE__*/_jsx(Popover, {
      trigger: Array.isArray(trigger) ? trigger.join(' ') : trigger,
      isOpen: isVisibleState,
      toggle: handleToggle,
      target: targetRef,
      className: BASE_CLASS,
      popperClassName: "popperClassName",
      innerClassName: CLASS_INNER,
      arrowClassName: BASE_CLASS + "-arrow",
      innerRef: outRef,
      hideArrow: hideArrow,
      placementPrefix: PREFIX_PLACEMENT,
      delay: DEFAULT_DELAY,
      placement: placement,
      offset: DEFAULT_OFFSET,
      children: function children(_ref2) {
        var update = _ref2.scheduleUpdate;
        return /*#__PURE__*/_jsxs(_Fragment, {
          children: [closeIcon && /*#__PURE__*/_jsx("div", {
            className: BASE_CLASS + "-closeIcon",
            onClick: handleToggle,
            children: closeIcon
          }), /*#__PURE__*/_jsx(ContentComponent, {
            update: update
          })]
        });
      }
    })]
  });
});
AtomPopover.displayName = 'AtomPopover';
export { PLACEMENTS as atomPopoverPositions };
export { TRIGGERS as atomPopoverTriggers };
export default AtomPopover;